@@ -167,26 +167,30 @@ cad.ThPb <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
     cad_helper(x,i2i=i2i,pch=pch,verticals=verticals,
                xlab=xlab,col=col,hide=hide,...)
 }
-#' @param detritus detrital \eqn{^{230}}Th correction (only applicable
-#'     when \code{x$format=1} or \code{2}).
+#' @param Th0i initial \eqn{^{230}}Th correction.
 #'
 #' \code{0}: no correction
 #'
 #' \code{1}: project the data along an isochron fit
 #'
-#' \code{2}: correct the data using an assumed initial
-#' \eqn{^{230}}Th/\eqn{^{232}}Th-ratio for the detritus.
-#'
-#' \code{3}: correct the data using the measured present day
-#' \eqn{^{230}}Th/\eqn{^{238}}U, \eqn{^{232}}Th/\eqn{^{238}}U and
-#' \eqn{^{234}}U/\eqn{^{238}}U-ratios in the detritus.
+#' \code{2}: if \code{x$format} is \code{1} or \code{2}, correct the
+#' data using the measured present day \eqn{^{230}}Th/\eqn{^{238}}U,
+#' \eqn{^{232}}Th/\eqn{^{238}}U and \eqn{^{234}}U/\eqn{^{238}}U
+#' activity ratios in the detritus. If \code{x$format} is \code{3} or
+#' \code{4}, correct the data using the measured
+#' \eqn{^{238}}U/\eqn{^{232}}Th activity ratio of the whole rock, as
+#' stored in \code{x} by the \code{read.data()} function.
 #'
+#' \code{3}: correct the data using an assumed initial
+#' \eqn{^{230}}Th/\eqn{^{232}}Th-ratio for the detritus (only relevant
+#' if \code{x$format} is \code{1} or \code{2}).
+#' 
 #' @rdname cad
 #' @export
 cad.ThU <- function(x,pch=NA,verticals=TRUE, xlab='age [ka]',
-                    col='black',i2i=FALSE,detritus=0,hide=NULL,...){
-    cad_helper(x,i2i=i2i,detritus=detritus,pch=pch,
-               verticals=verticals,xlab=xlab,col=col,hide=hide,...)
+                    col='black',Th0i=0,hide=NULL,...){
+    cad_helper(x,Th0i=Th0i,pch=pch,verticals=verticals,
+               xlab=xlab,col=col,hide=hide,...)
 }
 #' @rdname cad
 #' @export
@@ -238,13 +242,10 @@ cad.fissiontracks <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
                xlab=xlab,col=col,hide=hide,...)
 }
 
-cad_helper <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
-                       col='black',hide=NULL,type=4,cutoff.76=1100,
-                       cutoff.disc=discfilter(),common.Pb=0,
-                       i2i=FALSE,detritus=0,...){
-    tt <- get.ages(x,type=type,cutoff.76=cutoff.76,
-                   cutoff.disc=cutoff.disc,i2i=i2i,
-                   common.Pb=common.Pb,detritus=detritus,omit4c=hide)
-    cad.default(tt[,1],pch=pch,verticals=verticals,
-                xlab=xlab,col=col,hide=hide,...)
+cad_helper <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',col='black',
+                       hide=NULL,type=4,cutoff.76=1100,cutoff.disc=discfilter(),
+                       common.Pb=0,i2i=FALSE,Th0i=0,...){
+    tt <- get.ages(x,type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+                   i2i=i2i,common.Pb=common.Pb,Th0i=Th0i,omit4c=hide)
+    cad.default(tt[,1],pch=pch,verticals=verticals,xlab=xlab,col=col,hide=hide,...)
 }
