@@ -249,11 +249,11 @@
 #' concordia(UPb,show.age=2)
 #'
 #' dev.new()
-#' concordia(UPb,type=1,xlim=c(24.9,25.4),
+#' concordia(UPb,type=2,xlim=c(24.9,25.4),
 #'           ylim=c(0.0508,0.0518),ticks=249:254,exterr=TRUE)
 #'
 #' dev.new()
-#' concordia(UPb,type=2,show.age=2,anchor=list(TRUE,0))
+#' concordia(UPb,show.age=2,anchor=c(2,260))
 #'
 #' @references Ludwig, K.R., 1998. On the treatment of concordant
 #'     uranium-lead ages. Geochimica et Cosmochimica Acta, 62(4),
@@ -295,9 +295,9 @@ concordia <- function(x=NULL,tlim=NULL,alpha=0.05,type=1,
     }
     plot.concordia.line(x2calc,lims=lims,type=type,col=concordia.col,
                         alpha=alpha,exterr=exterr,ticks=ticks)
-    if (type==1) y <- data2york(X2plot,option=1)
-    else if (type==2) y <- data2york(X2plot,option=2)
-    else if (x$format%in%c(7,8) & type==3) y <- data2york(X2plot,option=5)
+    if (type==1) y <- data2york(X,option=1)
+    else if (type==2) y <- data2york(X,option=2)
+    else if (x$format%in%c(7,8) & type==3) y <- data2york(X,option=5)
     else stop('Concordia type incompatible with this input format.')
     scatterplot(y,alpha=alpha,show.numbers=show.numbers,
                 show.ellipses=1*(show.age!=3),levels=levels,
@@ -613,7 +613,7 @@ concordia.age <- function(x,i=NA,type=1,exterr=TRUE,alpha=0.05,...){
         if (type==3){
             cc4age <- cc
             type4age <- 3
-        } else { # use wetherill
+        } else { # use Wetherill
             cc4age <- concordia.comp(x,type=1)
             type4age <- 1
         }
@@ -646,7 +646,7 @@ concordia.age <- function(x,i=NA,type=1,exterr=TRUE,alpha=0.05,...){
 concordia_age_helper <- function(cc,d=diseq(),type=1,exterr=FALSE,...){
     if (type==1) Pb206U238 <- cc$x['Pb206U238']
     else if (type==2) Pb206U238 <- 1/cc$x['U238Pb206']
-    else if (type==3) Pb206U238 <- 1/cc$x['Pb206U238']
+    else if (type==3) Pb206U238 <- cc$x['Pb206U238']
     else stop('Incorrect concordia type.')
     midpoint <- get.Pb206U238.age(x=Pb206U238,d=d)[1]
     fit1 <- stats::optimise(LL.concordia.age,interval=c(0,midpoint),
@@ -694,20 +694,6 @@ concordia.comp <- function(x,type=1){
     out
 }
 
-# x is an object of class "terawasserburg"
-initial.concordia.age <- function(x,d=diseq()){
-    e <- eigen(x$cov)
-    v <- e$vectors[,1]
-    if (v[1]==0) return(get.Pb207Pb206.age(x$x['Pb207Pb206'],0,d=d)[1])
-    if (v[2]==0) return(get.Pb206U238.age(1/x$x['U238Pb206'],0,d=d)[1])
-    b <- v[1]/v[2] # slope of the ellipse
-    x0 <- x$x['U238Pb206']
-    y0 <- x$x['Pb207Pb206']
-    a <- y0 - b*x0
-    fit <- concordia.intersection.ab(a,b,exterr=FALSE,d=d)
-    fit[1]
-}
-
 mswd.concordia <- function(x,cc,type=1,tt=0,exterr=TRUE){
     SS.equivalence <- 
         LL.concordia.comp(mu=cc$x,x=x,type=type,mswd=TRUE)
@@ -759,7 +745,7 @@ LL.concordia.comp <- function(mu,x,type=1,mswd=FALSE,...){
         }
         X <- matrix(xi$x[j]-mu,1,2)
         covmat <- xi$cov[j,j]
-        if (mswd) out <- out + get.concordia.SS(X,covmat)
+        if (mswd) out <- out + stats::mahalanobis(x=X,center=FALSE,cov=covmat)
         else out <- out + LL.norm(X,covmat)
     }
     out
@@ -802,15 +788,11 @@ LL.concordia.age <- function(tt,cc,type=1,exterr=TRUE,d=diseq(),mswd=FALSE){
         E <- J %*% Lcov %*% t(J)
         covmat <- covmat + E
     }
-    if (mswd) out <- get.concordia.SS(dx,covmat)
+    if (mswd) out <- stats::mahalanobis(x=dx,center=FALSE,cov=covmat)
     else out <- LL.norm(dx,covmat)
     out
 }
 
-get.concordia.SS <- function(x,covmat){
-    x %*% solve(covmat) %*% t(x)
-}
-
 emptyconcordia <- function(tlim=NULL,alpha=0.05,type=1,exterr=TRUE,
                            concordia.col='darksalmon',ticks=5,...){
     if (is.null(tlim)){
