@@ -1,4 +1,4 @@
-#' @title Read geochronology data
+#' @title Read geochronological data
 #'
 #' @description
 #' Cast a \code{.csv} file or a matrix into one of \code{IsoplotR}'s
@@ -203,16 +203,20 @@
 #'
 #' @param d an object of class \code{\link{diseq}}.
 #' 
-#' @param Th02 2-element vector with the assumed initial
+#' @param Th02i 2-element vector with the assumed initial
 #'     \eqn{^{230}}Th/\eqn{^{232}}Th-ratio of the detritus (for
-#'     formats 1 and 2) or rock (for formats 3 and 4) and its standard
-#'     error.
+#'     Th-U formats 1 and 2) and its standard error.
 #' 
 #' @param Th02U48 9-element vector with the measured composition of
 #'     the detritus, containing \code{X=0/8}, \code{sX}, \code{Y=2/8},
 #'     \code{sY}, \code{Z=4/8}, \code{sZ}, \code{rXY}, \code{rXZ},
 #'     \code{rYZ}.
 #' 
+#' @param U8Th2 \eqn{^{238}}U/\eqn{^{232}}Th activity-ratio of the
+#'     whole rock. Used to estimate the initial
+#'     \eqn{^{230}}Th/\eqn{^{238}}U disequilibrium (for Th-U formats 3
+#'     and 4).
+#'
 #' @param ... optional arguments to the \code{read.csv} function
 #' 
 #' @seealso \code{\link{examples}}, \code{\link{settings}}
@@ -266,22 +270,25 @@ read.data <- function(x,...){ UseMethod("read.data",x) }
 #' @rdname read.data
 #' @export
 read.data.default <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
-                              Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
+                              Th02i=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                              U8Th2=0,...){
     X <- as.matrix(utils::read.table(x,sep=',',...))
     read.data.matrix(X,method=method,format=format,ierr=ierr,d=d,
-                     Th02=Th02,Th02U48=Th02U48)
+                     Th02i=Th02i,Th02U48=Th02U48,U8Th2=U8Th2)
 }
 #' @rdname read.data
 #' @export
 read.data.data.frame <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
-                                 Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
+                                 Th02i=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                                 U8Th2=0,...){
     read.data.matrix(as.matrix(x),method=method,format=format,
-                     ierr=ierr,d=d,Th02=Th02,Th02U48=Th02U48,...)
+                     ierr=ierr,d=d,Th02i=Th02i,Th02U48=Th02U48,U8Th2=U8Th2,...)
 }
 #' @rdname read.data
 #' @export
 read.data.matrix <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
-                             Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
+                             Th02i=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                             U8Th2=0,...){
     if (identical(method,'U-Pb')){
         out <- as.UPb(x,format=format,ierr=ierr,d=d)
     } else if (identical(method,'Pb-Pb')){
@@ -301,7 +308,8 @@ read.data.matrix <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
     } else if (identical(method,'Lu-Hf')){
         out <- as.LuHf(x,format=format,ierr=ierr)
     } else if (identical(method,'Th-U')){
-        out <- as.ThU(x,format=format,ierr=ierr,Th02=Th02,Th02U48=Th02U48)
+        out <- as.ThU(x,format=format,ierr=ierr,
+                      U8Th2=U8Th2,Th02i=Th02i,Th02U48=Th02U48)
     } else if (identical(method,'U-Th-He')){
         out <- as.UThHe(x,ierr=ierr)
     } else if (identical(method,'fissiontracks')){
@@ -665,12 +673,14 @@ as.PD <- function(x,classname,cnames,format,ierr){
     out$x <- insert.data(x=X,cnames=cnames,opt=opt)
     out
 }
-as.ThU <- function(x,format=1,ierr=1,Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0)){
+as.ThU <- function(x,format=1,ierr=1,U8Th2=0,Th02i=c(0,0),
+                   Th02U48=c(0,0,1e6,0,0,0,0,0,0)){
     out <- list()
     class(out) <- "ThU"
     out$x <- NA
     out$format <- format
-    out$Th02 <- Th02
+    out$U8Th2 <- U8Th2
+    out$Th02i <- Th02i
     out$Th02U48 <- Th02U48
     nc <- ncol(x)
     nr <- nrow(x)
